#!/bin/bash -f
#############################################################################
#$ -N Co.HCP.scf
#$ -cwd
#$ -o $HOME/3.320/LAB3/TEST/err.out
#$ -j y
#$ -S /bin/sh

########################################################
# This is a script to run PWSCF 2.1.2 calculations in
# the hpcbeo2 cluster.
# 
# This script will help you to get equilibrium lattice 
# parameter of HCP Co with varying c/a.
########################################################
# set the needed variables

MYDIR="3.320/LAB3/TEST"

LISTECUTRHO='250'
LISTECUTWFC='30'
LISTAK='9'
LISTCK='6'
LISTA='4.58'
# ABSOLUTE value of c ( not ratio )
LISTC='7.44'

USER=`whoami`

OUTDIR="/state/partition1/$USER"
PSEUDO_DIR="/home/lee0su/3.320"
OUTPUT="/home/$USER/$MYDIR"
PSEUDOFILE="Co.pz-nd-rrkjus.UPF"
PREFIX="Co.HCP.covera"

if [ ! -d $OUTDIR ]; then
	mkdir $OUTDIR
fi

if [ ! -d $OUTPUT ]; then
        echo $MYDIR does not exist, please create it first
	exit
fi

rm -f $OUTDIR/$PREFIX.*
#########################################################
# calculations

for ecutrho in $LISTECUTRHO
do
for ecutwfc in $LISTECUTWFC
do
for ak in $LISTAK
do
for ck in $LISTCK
do
for a in $LISTA
do
for c in $LISTC
do

cdm=`awk "BEGIN { printf \" %15.10f \",$c/$a }"`

INFILE="$PREFIX.scf.$a.$c.$ecutwfc.$ecutrho.$ak.$ck.in"
OUTFILE="$PREFIX.scf.$a.$c.$ecutwfc.$ecutrho.$ak.$ck.out"
rm -f $OUTPUT/$INFILE
rm -f $OUTPUT/$OUTFILE


cat > $OUTPUT/$INFILE << EOF
 &control
    calculation = 'scf'
    restart_mode='from_scratch'
    prefix='$PREFIX'
    tstress = .true.
    tprnfor = .true.
    outdir = '$OUTDIR'
    pseudo_dir = '$PSEUDO_DIR'
 /        
 &system    
    ibrav=  4
    celldm(1) = $a
    celldm(3) = $cdm
    nat=  2
    ntyp= 1
    ecutwfc = $ecutwfc 
    ecutrho = $ecutrho
    starting_magnetization(1) = 0.7
    occupations = 'smearing'
    degauss = 0.03
    smearing = 'cold'
    nspin = 2
 /
 &electrons
    mixing_beta = 0.7 
    conv_thr =  1.0d-8
 /
 ATOMIC_SPECIES
  Co  58.933  $PSEUDOFILE
 ATOMIC_POSITIONS (crystal)
  Co   0.3333333333  0.6666666667  0.25 
  Co   0.6666666667  0.3333333333  0.75 
 K_POINTS {automatic}
    $ak $ak $ck 0 0 0 
EOF

/home/lee0su/3.320/pw.x < $OUTPUT/$INFILE > $OUTPUT/$OUTFILE

done
done
done
done
done
done

rm -f $OUTDIR/$PREFIX.* 
